==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ProjectedVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ProjectedVolumeSourceFluent<A extends V1ProjectedVolumeSourceFluent<A>> extends Fluent<A>{


    public Integer getDefaultMode();
    public A withDefaultMode(Integer defaultMode);
    public Boolean hasDefaultMode();
    public A withNewDefaultMode(int arg1);
    public A withNewDefaultMode(String arg1);
    public A addToSources(int index,V1VolumeProjection item);
    public A setToSources(int index,V1VolumeProjection item);
    public A addToSources(V1VolumeProjection... items);
    public A addAllToSources(Collection<V1VolumeProjection> items);
    public A removeFromSources(V1VolumeProjection... items);
    public A removeAllFromSources(Collection<V1VolumeProjection> items);
    
/**
 * This method has been deprecated, please use method buildSources instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeProjection> getSources();
    public List<V1VolumeProjection> buildSources();
    public V1VolumeProjection buildSource(int index);
    public V1VolumeProjection buildFirstSource();
    public V1VolumeProjection buildLastSource();
    public V1VolumeProjection buildMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate);
    public A withSources(List<V1VolumeProjection> sources);
    public A withSources(V1VolumeProjection... sources);
    public Boolean hasSources();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSourceLike(V1VolumeProjection item);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> setNewSourceLike(int index,V1VolumeProjection item);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editSource(int index);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editFirstSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editLastSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate);

    public interface SourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeProjectionFluent<V1ProjectedVolumeSourceFluent.SourcesNested<N>>{

        
    public N and();    public N endSource();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ProjectedVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ProjectedVolumeSourceFluent<A extends V1ProjectedVolumeSourceFluent<A>> extends Fluent<A>{


    public Integer getDefaultMode();
    public A withDefaultMode(Integer defaultMode);
    public Boolean hasDefaultMode();
    public A addToSources(int index,V1VolumeProjection item);
    public A setToSources(int index,V1VolumeProjection item);
    public A addToSources(V1VolumeProjection... items);
    public A addAllToSources(Collection<V1VolumeProjection> items);
    public A removeFromSources(V1VolumeProjection... items);
    public A removeAllFromSources(Collection<V1VolumeProjection> items);
    
/**
 * This method has been deprecated, please use method buildSources instead.
 * @return The buildable object.
 */
@Deprecated public List<V1VolumeProjection> getSources();
    public List<V1VolumeProjection> buildSources();
    public V1VolumeProjection buildSource(int index);
    public V1VolumeProjection buildFirstSource();
    public V1VolumeProjection buildLastSource();
    public V1VolumeProjection buildMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate);
    public Boolean hasMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate);
    public A withSources(List<V1VolumeProjection> sources);
    public A withSources(V1VolumeProjection... sources);
    public Boolean hasSources();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> addNewSourceLike(V1VolumeProjection item);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> setNewSourceLike(int index,V1VolumeProjection item);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editSource(int index);
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editFirstSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editLastSource();
    public V1ProjectedVolumeSourceFluent.SourcesNested<A> editMatchingSource(io.kubernetes.client.fluent.Predicate<V1VolumeProjectionBuilder> predicate);

    public interface SourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1VolumeProjectionFluent<V1ProjectedVolumeSourceFluent.SourcesNested<N>>{

        
    public N and();    public N endSource();
}


}
